@@ -1,5 +1,6 @@
 import argparse
 import sys
+from saveddit.multireddit_downloader_config import MultiredditDownloaderConfig
 from saveddit.subreddit_downloader_config import SubredditDownloaderConfig
 from saveddit.user_downloader_config import UserDownloaderConfig
 from saveddit._version import __version__
@@ -79,6 +80,42 @@ def main():
                         help='Directory where saveddit will save downloaded content'
                         )
 
+    multireddit_parser = subparsers.add_parser('multireddit')
+    multireddit_parser.add_argument('subreddits',
+                        metavar='subreddits',
+                        nargs='+',
+                        action=UniqueAppendAction,
+                        help='Names of subreddits to download, e.g., aww, pics. The downloads will be stored in <OUTPUT_PATH>/www.reddit.com/m/aww+pics/.')
+    multireddit_parser.add_argument('-f',
+                        metavar='categories',
+                        default=MultiredditDownloaderConfig.DEFAULT_CATEGORIES,
+                        nargs='+',
+                        action=UniqueAppendAction,
+                        help='Categories of posts to download (default: %(default)s)')
+    multireddit_parser.add_argument('-l',
+                        default=MultiredditDownloaderConfig.DEFAULT_POST_LIMIT,
+                        metavar='post_limit',
+                        type=check_positive,
+                        help='Limit the number of submissions downloaded in each category (default: %(default)s, i.e., all submissions)')
+    multireddit_parser.add_argument('--skip-comments',
+                        default=False,
+                        action='store_true',
+                        help='When true, saveddit will not save comments to a comments.json file')
+    multireddit_parser.add_argument('--skip-meta',
+                        default=False,
+                        action='store_true',
+                        help='When true, saveddit will not save meta to a submission.json file on submissions')
+    multireddit_parser.add_argument('--skip-videos',
+                        default=False,
+                        action='store_true',
+                        help='When true, saveddit will not download videos (e.g., gfycat, redgifs, youtube, v.redd.it links)')
+    multireddit_parser.add_argument('-o',
+                        required=True,
+                        type=str,
+                        metavar='output_path',
+                        help='Directory where saveddit will save downloaded content'
+                        )
+
     user_parser = subparsers.add_parser('user')
     user_parser.add_argument('users',
                         metavar='users',
@@ -172,6 +209,44 @@ def main():
                         help='Directory where saveddit will save downloaded posts'
                         )
 
+    # user.multireddits subparser
+    submitted_parser = user_subparsers.add_parser('multireddits')
+    submitted_parser.add_argument('-n',
+                        metavar='names',
+                        default=None,
+                        nargs='+',
+                        action=UniqueAppendAction,
+                        help='Names of specific multireddits to download (default: %(default)s, i.e., all multireddits for this user)')
+    submitted_parser.add_argument('-f',
+                        metavar='categories',
+                        default=UserDownloaderConfig.DEFAULT_CATEGORIES,
+                        nargs='+',
+                        action=UniqueAppendAction,
+                        help='Categories of posts to download (default: %(default)s)')
+    submitted_parser.add_argument('--skip-comments',
+                        default=False,
+                        action='store_true',
+                        help='When true, saveddit will not save comments to a comments.json file for the submissions')
+    submitted_parser.add_argument('--skip-meta',
+                        default=False,
+                        action='store_true',
+                        help='When true, saveddit will not save meta to a submission.json file on submissions')
+    submitted_parser.add_argument('--skip-videos',
+                        default=False,
+                        action='store_true',
+                        help='When true, saveddit will not download videos (e.g., gfycat, redgifs, youtube, v.redd.it links)')
+    submitted_parser.add_argument('-l',
+                        default=UserDownloaderConfig.DEFAULT_POST_LIMIT,
+                        metavar='post_limit',
+                        type=check_positive,
+                        help='Limit the number of submissions downloaded (default: %(default)s, i.e., all submissions)')
+    submitted_parser.add_argument('-o',
+                        required=True,
+                        type=str,
+                        metavar='output_path',
+                        help='Directory where saveddit will save downloaded posts'
+                        )
+
     # user.upvoted subparser
     upvoted_parser = user_subparsers.add_parser('upvoted')
     upvoted_parser.add_argument('--skip-comments',
@@ -226,12 +301,19 @@ def main():
             downloader = SubredditDownloader(subreddit)
             downloader.download(args.o,
                                 categories=args.f, post_limit=args.l, skip_videos=args.skip_videos, skip_meta=args.skip_meta, skip_comments=args.skip_comments)
+    elif args.subparser_name == "multireddit":
+        from saveddit.multireddit_downloader import MultiredditDownloader
+        downloader = MultiredditDownloader(args.subreddits)
+        downloader.download(args.o,
+                            categories=args.f, post_limit=args.l, skip_videos=args.skip_videos, skip_meta=args.skip_meta, skip_comments=args.skip_comments)
     elif args.subparser_name == "user":
         from saveddit.user_downloader import UserDownloader
         downloader = UserDownloader()
         downloader.download_user_meta(args)
         if args.user_subparser_name == "comments":
             downloader.download_comments(args)
+        elif args.user_subparser_name == "multireddits":
+            downloader.download_multireddits(args)
         elif args.user_subparser_name == "submitted":
             downloader.download_submitted(args)
         elif args.user_subparser_name == "saved":
